==> tablegpt_agent-0.2.14.tar.gz: tablegpt_agent-0.2.14/docs/index.md <==
# Home

[![PyPI - Version](https://img.shields.io/pypi/v/tablegpt-agent.svg)](https://pypi.org/project/tablegpt-agent)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tablegpt-agent.svg)](https://pypi.org/project/tablegpt-agent)

## Introduction

tablegpt-agent is a pre-built agent for [TableGPT2 (huggingface)](https://huggingface.co/tablegpt/TableGPT2-7B), a series of LLMs for table-based question answering. This agent is built on top of the [Langgraph](https://www.langchain.com/langgraph) library and provides a user-friendly interface for interacting with TableGPT2.

## Table Of Contents

<!-- mkdocs requires 4 space to intent the list -->
- Tutorials
    - [Quickstart](tutorials/quickstart.md)
    - [Chat on Tabular Data](tutorials/chat-on-tabular-data.md)
    - [Continue Analysis on Generated Charts](tutorials/continue-analysis-on-generated-charts.md)
- How-To Guides
    - [Enhance TableGPT Agent with RAG](howto/retrieval.md)
    - [Persist Messages](howto/persist-messages.md)
    - [Incluster Code Execution](howto/incluster-code-execution.md)
    - [Normalize Datasets](howto/normalize-datasets.md)
- Explanation
    - [Agent Workflow](explanation/agent-workflow.md)
    - [File Reading](explanation/file-reading.md)
- [Reference](reference.md)

## Contributing

Thank you for your interest in TableGPT Agent. For more information on contributing, please see [the contributing guide](https://github.com/tablegpt/tablegpt-agent/blob/main/CONTRIBUTING.md).

## Acknowledgements

We extend our sincere gratitude to all contributors and collaborators who played a pivotal role in the development of tablegpt-agent. Special thanks to our team members and the open-source community, whose insights and feedback were invaluable throughout the project.

Thank you to our early users for their suggestions and engagement, which have greatly helped in refining and enhancing this tool.

==> tablegpt_agent-0.2.16.tar.gz: tablegpt_agent-0.2.16/docs/index.md <==
# Home

[![PyPI - Version](https://img.shields.io/pypi/v/tablegpt-agent.svg)](https://pypi.org/project/tablegpt-agent)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tablegpt-agent.svg)](https://pypi.org/project/tablegpt-agent)

## Introduction

tablegpt-agent is a pre-built agent for [TableGPT2 (huggingface)](https://huggingface.co/tablegpt/TableGPT2-7B), a series of LLMs for table-based question answering. This agent is built on top of the [Langgraph](https://www.langchain.com/langgraph) library and provides a user-friendly interface for interacting with TableGPT2.

## Table Of Contents

<!-- mkdocs requires 4 space to intent the list -->
- Tutorials
    - [Quickstart](tutorials/quick-start.ipynb)
    - [Chat on Tabular Data](tutorials/chat-on-tabular-data.ipynb)
    - [Continue Analysis on Generated Charts](tutorials/continue-analysis-on-generated-charts.ipynb)
- How-To Guides
    - [Enhance TableGPT Agent with RAG](howto/retrieval.ipynb)
    - [Persist Messages](howto/persist-messages.ipynb)
    - [Incluster Code Execution](howto/incluster-code-execution.md)
    - [Normalize Datasets](howto/normalize-datasets.ipynb)
- Explanation
    - [Agent Workflow](explanation/agent-workflow.md)
    - [File Reading](explanation/file-reading.ipynb)
- [Reference](reference.md)

## Contributing

Thank you for your interest in TableGPT Agent. For more information on contributing, please see [the contributing guide](https://github.com/tablegpt/tablegpt-agent/blob/main/CONTRIBUTING.md).

## Acknowledgements

We extend our sincere gratitude to all contributors and collaborators who played a pivotal role in the development of tablegpt-agent. Special thanks to our team members and the open-source community, whose insights and feedback were invaluable throughout the project.

Thank you to our early users for their suggestions and engagement, which have greatly helped in refining and enhancing this tool.
